==> yawp-1.21.4-fabric-0.6.2-beta1-sources.jar: de/z0rdak/yawp/mixin/flag/player/FarmLandBlockMixin.java <==
package de.z0rdak.yawp.mixin.flag.player;

import de.z0rdak.yawp.api.FlagEvaluator;
import de.z0rdak.yawp.api.events.region.FlagCheckEvent;
import de.z0rdak.yawp.platform.Services;
import net.minecraft.class_1297;
import net.minecraft.class_1657;
import net.minecraft.class_1937;
import net.minecraft.class_2248;
import net.minecraft.class_2338;
import net.minecraft.class_2344;
import net.minecraft.class_2680;
import org.spongepowered.asm.mixin.Mixin;
import org.spongepowered.asm.mixin.injection.At;
import org.spongepowered.asm.mixin.injection.Inject;
import org.spongepowered.asm.mixin.injection.callback.CallbackInfo;

import static de.z0rdak.yawp.core.flag.RegionFlag.*;
import static de.z0rdak.yawp.handler.HandlerUtil.*;
import static de.z0rdak.yawp.api.MessageSender.sendFlagMsg;

@Mixin(class_2344.class)
public abstract class FarmLandBlockMixin extends class_2248 {

    // Dummy constructor needed to allow inheriting from Block, which in turn is needed to call super.fallOn()
    // This constructor is not actually injected.
    public FarmLandBlockMixin(class_2251 properties) {
        super(properties);
    }

    @Inject(method = "fallOn", at = @At(value = "HEAD"), cancellable = true)
    private void onTrampleFarmland(class_1937 world, class_2680 state, class_2338 pos, class_1297 trampler, float fallDistance, CallbackInfo ci) {
        if (isServerSide(world)) {
            FlagCheckEvent checkEvent = new FlagCheckEvent(pos, TRAMPLE_FARMLAND, getDimKey(world), null);
            if (Services.EVENT.post(checkEvent)) {
                return;
            }
            FlagEvaluator.processCheck(checkEvent, deny -> {
                if (deny.getFlagCheck().getPlayer() != null) {
                    sendFlagMsg(deny);
                }
                super.method_9554(world, state, pos, trampler, fallDistance);
                ci.cancel();
            });

            if (trampler instanceof class_1657 player) {
                checkEvent = new FlagCheckEvent(pos, TRAMPLE_FARMLAND_PLAYER, getDimKey(world), player);
                if (Services.EVENT.post(checkEvent)) {
                    return;
                }
                FlagEvaluator.processCheck(checkEvent, deny -> {
                    sendFlagMsg(deny);
                    super.method_9554(world, state, pos, trampler, fallDistance);
                    ci.cancel();
                });
            } else {
                checkEvent = new FlagCheckEvent(pos, TRAMPLE_FARMLAND_OTHER, getDimKey(world), null);
                if (Services.EVENT.post(checkEvent)) {
                    return;
                }
                FlagEvaluator.processCheck(checkEvent, deny -> {
                    super.method_9554(world, state, pos, trampler, fallDistance);
                    ci.cancel();
                });
                checkEvent = new FlagCheckEvent(pos, MOB_GRIEFING, getDimKey(world), null);
                if (Services.EVENT.post(checkEvent)) {
                    return;
                }
                FlagEvaluator.processCheck(checkEvent, deny -> {
                    super.method_9554(world, state, pos, trampler, fallDistance);
                    ci.cancel();
                });
            }
        }
    }
}

==> yawp-1.21.5-fabric-0.5.3-beta1-sources.jar: de/z0rdak/yawp/mixin/flag/player/FarmLandBlockMixin.java <==
package de.z0rdak.yawp.mixin.flag.player;

import de.z0rdak.yawp.api.FlagEvaluator;
import de.z0rdak.yawp.api.events.region.FlagCheckEvent;
import de.z0rdak.yawp.platform.Services;
import net.minecraft.class_1297;
import net.minecraft.class_1657;
import net.minecraft.class_1937;
import net.minecraft.class_2248;
import net.minecraft.class_2338;
import net.minecraft.class_2344;
import net.minecraft.class_2680;
import org.spongepowered.asm.mixin.Mixin;
import org.spongepowered.asm.mixin.injection.At;
import org.spongepowered.asm.mixin.injection.Inject;
import org.spongepowered.asm.mixin.injection.callback.CallbackInfo;

import static de.z0rdak.yawp.core.flag.RegionFlag.*;
import static de.z0rdak.yawp.handler.HandlerUtil.*;
import static de.z0rdak.yawp.api.MessageSender.sendFlagMsg;

@Mixin(class_2344.class)
public abstract class FarmLandBlockMixin extends class_2248 {

    // Dummy constructor needed to allow inheriting from Block, which in turn is needed to call super.fallOn()
    // This constructor is not actually injected.
    public FarmLandBlockMixin(class_2251 properties) {
        super(properties);
    }

    @Inject(method = "fallOn", at = @At(value = "HEAD"), cancellable = true)
    private void onTrampleFarmland(class_1937 world, class_2680 state, class_2338 pos, class_1297 trampler, double fallDistance, CallbackInfo ci) {
        if (isServerSide(world)) {
            FlagCheckEvent checkEvent = new FlagCheckEvent(pos, TRAMPLE_FARMLAND, getDimKey(world), null);
            if (Services.EVENT.post(checkEvent)) {
                return;
            }
            FlagEvaluator.processCheck(checkEvent, deny -> {
                if (deny.getFlagCheck().getPlayer() != null) {
                    sendFlagMsg(deny);
                }
                super.method_9554(world, state, pos, trampler, fallDistance);
                ci.cancel();
            });

            if (trampler instanceof class_1657 player) {
                checkEvent = new FlagCheckEvent(pos, TRAMPLE_FARMLAND_PLAYER, getDimKey(world), player);
                if (Services.EVENT.post(checkEvent)) {
                    return;
                }
                FlagEvaluator.processCheck(checkEvent, deny -> {
                    sendFlagMsg(deny);
                    super.method_9554(world, state, pos, trampler, fallDistance);
                    ci.cancel();
                });
            } else {
                checkEvent = new FlagCheckEvent(pos, TRAMPLE_FARMLAND_OTHER, getDimKey(world), null);
                if (Services.EVENT.post(checkEvent)) {
                    return;
                }
                FlagEvaluator.processCheck(checkEvent, deny -> {
                    super.method_9554(world, state, pos, trampler, fallDistance);
                    ci.cancel();
                });
                checkEvent = new FlagCheckEvent(pos, MOB_GRIEFING, getDimKey(world), null);
                if (Services.EVENT.post(checkEvent)) {
                    return;
                }
                FlagEvaluator.processCheck(checkEvent, deny -> {
                    super.method_9554(world, state, pos, trampler, fallDistance);
                    ci.cancel();
                });
            }
        }
    }
}
